@@ -61,6 +61,7 @@
 #include "assetswap.hpp"
 #include "autocovariances.hpp"
 #include "barrieroption.hpp"
+#include "basismodels.hpp"
 #include "basketoption.hpp"
 #include "batesmodel.hpp"
 #include "bermudanswaption.hpp"
@@ -105,6 +106,8 @@
 #include "fastfouriertransform.hpp"
 #include "fdheston.hpp"
 #include "fdmlinearop.hpp"
+#include "fdcev.hpp"
+#include "fdsabr.hpp"
 #include "forwardoption.hpp"
 #include "forwardrateagreement.hpp"
 #include "functions.hpp"
@@ -173,6 +176,7 @@
 #include "sampledcurve.hpp"
 #include "schedule.hpp"
 #include "shortratemodels.hpp"
+#include "sofrfutures.hpp"
 #include "solvers.hpp"
 #include "spreadoption.hpp"
 #include "squarerootclvmodel.hpp"
@@ -184,6 +188,7 @@
 #include "swaptionvolatilitycube.hpp"
 #include "swaptionvolatilitymatrix.hpp"
 #include "termstructures.hpp"
+#include "timegrid.hpp"
 #include "timeseries.hpp"
 #include "tqreigendecomposition.hpp"
 #include "tracing.hpp"
@@ -310,12 +315,6 @@ test_suite* init_unit_test_suite(int, char* []) {
         #else
         "QuantLib " QL_VERSION
         #endif
-        "\n  QL_NEGATIVE_RATES "
-        #ifdef QL_NEGATIVE_RATES
-        "       defined"
-        #else
-        "     undefined"
-        #endif
         "\n  QL_EXTRA_SAFETY_CHECKS "
         #ifdef QL_EXTRA_SAFETY_CHECKS
         "  defined"
@@ -391,6 +390,8 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(FastFourierTransformTest::suite());
     test->add(FdHestonTest::suite(speed));
     test->add(FdmLinearOpTest::suite());
+    test->add(FdCevTest::suite(speed));
+    test->add(FdSabrTest::suite(speed));
     test->add(ForwardOptionTest::suite());
     test->add(ForwardRateAgreementTest::suite());
     test->add(FunctionsTest::suite());
@@ -453,6 +454,7 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(SwaptionVolatilityCubeTest::suite());
     test->add(SwaptionVolatilityMatrixTest::suite());
     test->add(TermStructureTest::suite());
+    test->add(TimeGridTest::suite());
     test->add(TimeSeriesTest::suite());
     test->add(TqrEigenDecompositionTest::suite());
     test->add(TracingTest::suite());
@@ -463,6 +465,7 @@ test_suite* init_unit_test_suite(int, char* []) {
     // tests for experimental classes
     test->add(AmortizingBondTest::suite());
     test->add(AsianOptionTest::experimental());
+    test->add(BasismodelsTest::suite());
     test->add(BarrierOptionTest::experimental());
     test->add(DoubleBarrierOptionTest::experimental());
     test->add(BlackDeltaCalculatorTest::suite());
@@ -495,6 +498,7 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(PartialTimeBarrierOptionTest::suite());
     test->add(QuantoOptionTest::experimental());
     test->add(RiskNeutralDensityCalculatorTest::experimental(speed));
+    test->add(SofrFuturesTest::suite());
     test->add(SpreadOptionTest::suite());
     test->add(SquareRootCLVModelTest::experimental());
     test->add(SwingOptionTest::suite(speed));
